package com.ruoyi.system.mapper.fgw;

import java.util.List;
import com.ruoyi.system.domain.fgw.FgwDbd;
import org.apache.ibatis.annotations.Param;

/**
 * 发改委_督办单Mapper接口
 * 
 * @author ruoyi
 * @date 2023-03-24
 */
public interface FgwDbdMapper 
{
    /**
     * 查询发改委_督办单
     * 
     * @param id 发改委_督办单主键
     * @return 发改委_督办单
     */
    public FgwDbd selectFgwDbdById(Long id);

    /**
     * 查询发改委_督办单列表
     * 
     * @param fgwDbd 发改委_督办单
     * @return 发改委_督办单集合
     */
    public List<FgwDbd> selectFgwDbdList(FgwDbd fgwDbd);

    /**
     * 新增发改委_督办单
     * 
     * @param fgwDbd 发改委_督办单
     * @return 结果
     */
    public int insertFgwDbd(FgwDbd fgwDbd);

    /**
     * 修改发改委_督办单
     * 
     * @param fgwDbd 发改委_督办单
     * @return 结果
     */
    public int updateFgwDbd(FgwDbd fgwDbd);

    /**
     * 删除发改委_督办单
     * 
     * @param id 发改委_督办单主键
     * @return 结果
     */
    public int deleteFgwDbdById(Long id);

    /**
     * 批量删除发改委_督办单
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFgwDbdByIds(Long[] ids);

    void updateFgwDbdByDbnrId(@Param("xmId") Long id, @Param("type")String type);

    List<FgwDbd> selectFgwDbdYjxmNum();

    List<FgwDbd> selectFgwDbdCqxmNum();
}
