package com.ruoyi.web.controller.fgw;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.fgw.FgwDbd;
import com.ruoyi.system.service.fgw.IFgwDbdService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 发改委_督办单Controller
 * 
 * @author ruoyi
 * @date 2023-03-24
 */
@RestController
@RequestMapping("/fgw/dbd")
public class FgwDbdController extends BaseController
{
    @Autowired
    private IFgwDbdService fgwDbdService;

    /**
     * 查询发改委_督办单列表
     */
    @PreAuthorize("@ss.hasPermi('fgw:dbd:list')")
    @GetMapping("/list")
    public TableDataInfo list(FgwDbd fgwDbd)
    {
        startPage();
        List<FgwDbd> list = fgwDbdService.selectFgwDbdList(fgwDbd);
        return getDataTable(list);
    }

    /**
     * 导出发改委_督办单列表
     */
    @PreAuthorize("@ss.hasPermi('fgw:dbd:export')")
    @Log(title = "发改委_督办单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FgwDbd fgwDbd)
    {
        List<FgwDbd> list = fgwDbdService.selectFgwDbdList(fgwDbd);
        ExcelUtil<FgwDbd> util = new ExcelUtil<FgwDbd>(FgwDbd.class);
        util.exportExcel(response, list, "发改委_督办单数据");
    }

    /**
     * 获取发改委_督办单详细信息
     */
    @PreAuthorize("@ss.hasPermi('fgw:dbd:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(fgwDbdService.selectFgwDbdById(id));
    }

    /**
     * 新增发改委_督办单
     */
    @PreAuthorize("@ss.hasPermi('fgw:dbd:add')")
    @Log(title = "发改委_督办单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FgwDbd fgwDbd)
    {
        return fgwDbdService.insertFgwDbd(fgwDbd);
    }

    /**
     * 修改发改委_督办单
     */
    @PreAuthorize("@ss.hasPermi('fgw:dbd:edit')")
    @Log(title = "发改委_督办单", businessType = BusinessType.UPDATE)
    @PostMapping("put")
    public AjaxResult edit(@RequestBody FgwDbd fgwDbd)
    {
        return toAjax(fgwDbdService.updateFgwDbd(fgwDbd));
    }

    /**
     * 删除发改委_督办单
     */
    @PreAuthorize("@ss.hasPermi('fgw:dbd:remove')")
    @Log(title = "发改委_督办单", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fgwDbdService.deleteFgwDbdByIds(ids));
    }
}
